@@ -1,7 +1,9 @@
 #! /usr/bin/env bash
 set -xe
 
-export VERSION=1.0.1
+export VERSION=1.1.1
+
+apt-get -y install build-essential python-dev python-virtualenv
 
 rm -rf build
 
@@ -10,12 +12,13 @@ virtualenv build/usr/share/python/graphite
 build/usr/share/python/graphite/bin/pip install -U pip distribute
 build/usr/share/python/graphite/bin/pip uninstall -y distribute
 
-build/usr/share/python/graphite/bin/pip install graphite-api[sentry,cyanite] gunicorn==18.0
+build/usr/share/python/graphite/bin/pip install graphite-api[sentry,cyanite] gunicorn==18.0 virtualenv-tools
 
 find build ! -perm -a+r -exec chmod a+r {} \;
 
 cd build/usr/share/python/graphite
-virtualenv-tools --update-path /usr/share/python/graphite
+sed -i "s/'\/bin\/python'/\('\/bin\/python','\/bin\/python2'\)/g" lib/python2.7/site-packages/virtualenv_tools.py
+./bin/virtualenv-tools --update-path /usr/share/python/graphite
 cd -
 
 find build -iname *.pyc -exec rm {} \;
